; ***********************************************
; xy_2.ncl
;
; Concepts illustrated:
;   - Drawing an XY plot with multiple curves
;   - Changing the line color for multiple curves in an XY plot
;   - Changing the line thickness for multiple curves in an XY plot
;   - Drawing XY plot curves with both lines and markers
;   - Changing the default markers in an XY plot
;   - Making all curves in an XY plot solid
;
; ***********************************************
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"

;************************************************
begin


  taille     = 0.25
  first      = 0.25
  largeur    = 0.60

  
;************************************************
; read in data
;************************************************

  ncol = 2
  datap = readAsciiTable("../../INPUTS/lownox/aer.ter/aer.precursor", ncol, "float", 0)
  VOC           = datap(:,1)

  ncol = 2
  datap2 = readAsciiTable("outfiles/fit6.precursor.ter.lownox.no56", ncol, "float", 0)
  FVOC           = datap2(:,1)


  ncol = 7
  data = readAsciiTable("../../INPUTS/lownox/aer.ter/aer.cdis_all.6", ncol, "float", 0)
  times         = data(:,0)
  VB1           = data(:,1)  
  VB2           = data(:,2) 
  VB3           = data(:,3)
  VB4           = data(:,4)
  VB5           = data(:,5)
  VB6           = data(:,6)

  VB1@_FillValue = -999.
  VB2@_FillValue = -999.
  VB3@_FillValue = -999.
  VB4@_FillValue = -999.
  VB5@_FillValue = -999.
  VB6@_FillValue = -999.

  times_hour = times/3600.
  indd = ind(floattoint(times_hour)%12.eq.0 .AND.times_hour.eq.floattoint(times_hour))
  indmn = ind(times_hour.eq.floattoint(times_hour))
  time_label = sprinti("%0.2i",floattoint(times_hour))

;fitted fit6.c12.lownox.no56
  ncol = 7
  data3 = readAsciiTable("outfiles/fit6.ter.lownox.no56", ncol, "float", 0)
  FVB1           = data3(:,1)    
  FVB2           = data3(:,2)   
  FVB3           = data3(:,3)
  FVB4           = data3(:,4)
  FVB5           = data3(:,5)
  FVB6           = data3(:,6)


;************************************************
; to plot multiple lines, you must put them into
; a mulidimensional array
;************************************************
 pdata      = new((/14,dimsizes(VB1)/),float)

 pdata(0,:) = VB1           ;logC* 3-5
 pdata(1,:) = VB2           ;logC* 1-3  blue
 pdata(2,:) = VB3           ;logC* 0-1  cyan 
 pdata(3,:) = VB4               ;logC* 0->1  black
 pdata(4,:) = VB5    ;orange
 pdata(5,:) = VB6    ;brown
 pdata(6,:) = (VOC)/3.  ;precursor green

 pdata(7,:) = FVB1
 pdata(8,:) = FVB2
 pdata(9,:) = FVB3
 pdata(10,:) = FVB4
 pdata(11,:) = FVB5    ;orange
 pdata(12,:) = FVB6    ;brown
 pdata(13,:) = (FVOC)/3.  ;precursor green

;print(pdata(0,:)+" "+pdata(1,:))
;************************************************
; plotting parameters
;************************************************
; wks   = gsn_open_wks ("x11","xy")                  ; open workstation
 wks   = gsn_open_wks ("ps","fig6.ter.lownox.no56")                  ; open workstation

 res                   = True                      ; plot mods desired
 res@tiMainString      = "OA (gas+aer) in various VBS bins"        ; add title
 ;res@tiMainString      = "OA (gas+aer) mass (ug/m3) in various VBS bins"        ; add title

; note a similiar resource is xyLineThicknessF, which will effect all
; the lines in the array.
 res@xyLineThicknesses = (/2.,2.,2.,2.,2.,2.,2.,3.,2.,2.,2.,2.,2.,2.,2.,3./)               ; make 2nd lines thicker
res@xyDashPatterns = (/0,0,0,0,0,0,0,1,1,1,1,1,1,1/)
 res@xyLineColors      = (/"purple","blue","cyan","black","orange","red","green","purple","blue","cyan","black","orange","red","green"/)          ; change line color

  res@vpXF              = 0.2
  res@vpYF              = (first+2*taille)+0.09*2
  res@vpWidthF          = largeur
  res@vpHeightF         = taille
  res@tmLabelAutoStride = True

     res@tiYAxisPosition       = "Center"
     res@tiYAxisFontHeightF    = 0.02
     res@tiYAxisFontThicknessF = 0.01

     res@tiXAxisString    = "Time (Hours)"
     res@tiYAxisString    = "OA (molecules/cm3)"
     res@tmYROn              = True
     res@tmXBOn              = True
     res@tmXTOn              = False

     res@tmXBMode            = "Explicit"              ; explicit labels
     res@tmXBValues          = times(indd)
     res@tmXBLabels          = time_label(indd);
     ;res@tmXBMinorValues     = times(indmn)
     res@trXMinF             = 0;min(x_plot(1,:nb_t1-1))
     res@trXMaxF             = 121*3600.;max(x_plot(1,:nb_t1-1))
     ;res@trYMaxF             = ymax ;18 ;25
     ;res@trYMinF             = 0
     res@tmXBLabelFontThicknessF = 0.01

     res@gsnDraw                   = False
     res@gsnFrame                  = False

 times@units = "seconds"
 plot  = gsn_csm_xy (wks,times,pdata,res) ; create plot

var_to_plot = (/"VB1(5->3)  ","VB2(3->1)  ","VB3(1->0)  ","VB4(0->-1) ","VB5(-1->-2)","VB6(<-2)   ","VOC/3      "/)
       lgres                    = True
       lgres@lgLineColors       = res@xyLineColors
       lgres@lgLineThicknessF   = (/2,2,2,2,2,2,2/)
       lgres@vpWidthF           = 0.16
       lgres@vpHeightF          = 0.2 
       lgres@txFontHeightF      = 1.2
       lgres@txFontThicknessF   = 0.08
       lgres@lgPerimOn          = False
       lgres@lgDashIndexes      = (/0,0,0,0,0,0,0/)
       lgres@lgLineLabelStrings = (/"","","","","","","",""/)
       lgres@lgPerimFillColor   = 0
       lgres@lgPerimFill        = 0

  ;     gsn_legend_ndc(wks,8,var_to_plot,0.85,0.9,lgres)

     txres                    = True                            
     txres@txFontHeightF      = 0.015;
     txres@txFontThicknessF   = 0.08
     txres@txJust             = "BottomLeft"
     text = new(8,graphic)
     colors = res@xyLineColors
     do ii = 0, 6
        txres@txFontColor = colors(ii)
        label = var_to_plot(ii)
        gsn_text_ndc(wks,label,0.85, 0.9-(0.03*ii), txres)
     end do

  draw(plot)
  frame(wks)

end

