; ***********************************************
; xy_2.ncl
;
; Concepts illustrated:
;   - Drawing an XY plot with multiple curves
;   - Changing the line color for multiple curves in an XY plot
;   - Changing the line thickness for multiple curves in an XY plot
;   - Drawing XY plot curves with both lines and markers
;   - Changing the default markers in an XY plot
;   - Making all curves in an XY plot solid
;
; ***********************************************
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"

;************************************************
begin


  taille     = 0.25
  first      = 0.25
  largeur    = 0.60


;************************************************
; read in data
;************************************************


  ncol = 15
  data = readAsciiTable("aer.koh_vbs", ncol, "float", 2)   ; almas files
  data2 = readAsciiTable("aer.cdis_all", ncol, "float", 2)    ;julia's files
  times         = data(:,0)
  VB1           = data(:,1)    ;logC* >8
  VB2           = data(:,2)    ;logC* 7-8
  VB3           = data(:,3)
  VB4           = data(:,4)
  VB5           = data(:,5)
  VB6           = data(:,6)
  VB7           = data(:,7)
  VB8           = data(:,8)
  VB9           = data(:,9)
  VB10           = data(:,10)
  VB11           = data(:,11)
  VB12           = data(:,12)
  VB13           = data(:,13)
  VB14           = data(:,14)   ;logC* <-4

  VB1@_FillValue = -999.
  VB2@_FillValue = -999.
  VB3@_FillValue = -999.
  VB4@_FillValue = -999.
  VB5@_FillValue = -999.
  VB6@_FillValue = -999.
  VB7@_FillValue = -999.
  VB8@_FillValue = -999.
  VB9@_FillValue = -999.
  VB10@_FillValue = -999.
  VB11@_FillValue = -999.
  VB12@_FillValue = -999.
  VB13@_FillValue = -999.
  VB14@_FillValue = -999.


  VVB1           = data2(:,1)    ;logC* >8
  VVB2           = data2(:,2)    ;logC* 7-8
  VVB3           = data2(:,3)
  VVB4           = data2(:,4)
  VVB5           = data2(:,5)
  VVB6           = data2(:,6)
  VVB7           = data2(:,7)
  VVB8           = data2(:,8)
  VVB9           = data2(:,9)
  VVB10           = data2(:,10)
  VVB11           = data2(:,11)
  VVB12           = data2(:,12)
  VVB13           = data2(:,13)
  VVB14           = data2(:,14)   ;logC* <-4


;************************************************
; to plot multiple lines, you must put them into
; a mulidimensional array
;************************************************
 pdata      = new((/7,dimsizes(VB1)/),float)

 pdata(0,:) = (VB1*VVB1+VB2*VVB2+VB3*VVB3+VB4*VVB4)/(VVB1+VVB2+VVB3+VVB4)   ;logC* >5
 pdata(1,:) = (VB5*VVB5+VB6*VVB6)/(VVB5+VVB6)           ;logC* 3->5  blue
 pdata(2,:) = (VB7*VVB7+VB8*VVB8)/(VVB7+VVB8)           ;logC* 1->3  cyan
 pdata(3,:) = VB9               ;logC* 0->1  black
 pdata(4,:) = VB10    ;orange
 pdata(5,:) = VB11    ;brown
 pdata(6,:) = (VB12*VVB12+VB13*VVB13+VB14*VVB14)/(VVB12+VVB13+VVB14)  ;logC* < -2


; convert into hours 1/kOH for OH=2e6 molec/cc
 pdata=1./(pdata*2e6)/3600.

; average values for each bin
 avgdata=dim_avg_n(pdata,1)
 print(avgdata)

; print(pdata(0,:)+" "+pdata(1,:)+" "+pdata(2,:)+" "+pdata(3,:)+" "+pdata(4,:)+" "+pdata(5,:)+" "+pdata(6,:))
;************************************************
; plotting parameters
;************************************************
; wks   = gsn_open_wks ("x11","xy")                  ; open workstation
 wks   = gsn_open_wks ("ps","xy")                  ; open workstation

 res                   = True                      ; plot mods desired
 res@tiMainString      = "kOH weighted by gas-phase conc (cc/molec/s) in VBS"        ; add title

; note a similiar resource is xyLineThicknessF, which will effect all
; the lines in the array.
 res@xyLineThicknesses = (/2.,2.,2.,2.,2.,2.,2.,2.,2.,3./)               ; make 2nd lines thicker

 res@xyLineColors      = (/"purple","blue","cyan","black","orange","brown","red","green"/)          ; change line color

  res@vpXF              = 0.2
  res@vpYF              = (first+2*taille)+0.09*2
  res@vpWidthF          = largeur
  res@vpHeightF         = taille
  res@tmLabelAutoStride = True

 times@units = "seconds"
 plot  = gsn_csm_xy (wks,times,pdata,res) ; create plot

end

